@@ -23,6 +23,7 @@
 */
 
 /*IN*/
+#define _GNU_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -211,7 +212,7 @@ int   *timeout;		/* max time to wait for reply (seconds) */
 #define DATLEN 16		/* max. number of char in date literal */
 
 /*UF    main function */
-main(argc, argv)
+int main(argc, argv)
 int     argc;
 char   *argv[];
 
@@ -255,8 +256,6 @@ char   *argv[];
     char   *user = NULL;	/* user name */
     char   *password = NULL;	/* password (not implemented) */
     char    userbuf[L_cuserid+1];
-    char resolved_name[MAXPATHLEN + 1];
-    char *result_name;
 
 
     /* Validate command-line arguments */
